@@ -80,6 +80,8 @@ infixr 3 >|                 -- another name for seq
 infixl 6 $||, $|            -- strategic function application (seq and par)
 infixl 9 .|, .||, -|, -||   -- strategic (inverse) function composition
 
+infixl 0 `seq`
+
 -- We need 'pseq', not the Prelude 'seq' here.  See the documentation
 -- with 'pseq' in Control.Parallel.
 seq = Parallel.pseq
@@ -508,6 +510,7 @@ seqList strat []     = ()
 seqList strat (x:xs) = strat x `seq` (seqList strat xs)
 
 -- | Sequentially applies a strategy to the first n elements of a list.
+{-# SPECIALISE seqListN :: Int -> Strategy b -> Strategy [b] #-}
 seqListN :: (Integral a) => a -> Strategy b -> Strategy [b]
 seqListN n strat []     = ()
 seqListN 0 strat xs     = ()
